#!/usr/bin/env python
# -----------------------------------------------------------------------------
# Script developed by A. Saraiva-Souza, research scientist
# Description: Generates the anatase TiO₂ structure with space group I4₁/amd,
#              and exports it to a properly symmetrized CIF file.
# -----------------------------------------------------------------------------

from pymatgen.core import Structure, Lattice
from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
from pymatgen.io.cif import CifWriter
import warnings
warnings.filterwarnings("ignore", category=DeprecationWarning)

def create_anatase_structure():
    # Optimized lattice parameters (Angstrom)
    a = 3.784
    c = 9.514
    u = 0.2079  # internal parameter of oxygen

    # Conventional tetragonal lattice
    lattice = Lattice.tetragonal(a, c)

    # Full species and crystallographic positions for anatase
    species = ['Ti', 'Ti', 'Ti', 'Ti', 'O', 'O', 'O', 'O', 'O', 'O', 'O', 'O']
    positions = [
        [0.0, 0.0, 0.0],           # Ti (4a)
        [0.0, 0.5, 0.25],          # generated by symmetry (Ti)
        [0.5, 0.5, 0.5],           # generated by symmetry (Ti)
        [0.5, 0.0, 0.75],          # generated by symmetry (Ti)
        [0.0, 0.0, u],             # O (8e)
        [0.0, 0.0, 1 - u],         # O (8e)
        [0.0, 0.5, 0.25 + u],      # generated by symmetry (O)
        [0.0, 0.5, 0.25 - u],      # generated by symmetry (O)
        [0.5, 0.5, 0.5 + u],       # generated by symmetry (O)
        [0.5, 0.5, 0.5 - u],       # generated by symmetry (O)
        [0.5, 0.0, 0.75 + u],      # generated by symmetry (O)
        [0.5, 0.0, 0.75 - u]       # generated by symmetry (O)
    ]

    # Create full structure directly
    structure = Structure(lattice, species, positions)

    # Analyze and standardize
    sga = SpacegroupAnalyzer(structure, symprec=1e-3)
    conventional_structure = sga.get_conventional_standard_structure()

    return conventional_structure

# Create full anatase structure
anatase = create_anatase_structure()

# Confirm space group
sga = SpacegroupAnalyzer(anatase, symprec=1e-3)
print(f"Confirmed space group: {sga.get_space_group_symbol()} ({sga.get_space_group_number()})")

# Export correct CIF
writer = CifWriter(anatase, symprec=1e-3)
writer.write_file("TiO2_anatase_I41amd.cif")

print("✅ Anatase structure with I4₁/amd symmetry saved as TiO2_anatase_I41amd.cif")
